@@ -1015,16 +1015,16 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000, for
                             curadd    = curadd    * len(adimnoiterin[ivsdin][i])
                             # curaddout = curaddout * dimnoiteroutref[i]
                     pos    = pos    + curadd
-                #ahunkin.append(dataicecubein[ivsdin][pos:(pos+alendfuncin[ivsdin])])
+                ahunkin.append(dataicecubein[ivsdin][pos:(pos+alendfuncin[ivsdin])])
                 shapein.append([len(e) for e in adimfuncin[ivsdin]])
                 #ahunkin[ivsdin].shape = [len(e) for e in adimfuncin[ivsdin]]
             # we are in the special case of an extra dimension to be prepended to the input
             if (list() in shapein) and (forcearray):
                 for ivsdin,evsdin in enumerate(vsdin):
-                    ahunkin.append(np.zeros([1]+shapein[ivsdin]))
+                    ahunkin.shape [1]+shapein[ivsdin])
             else:
                 for ivsdin,evsdin in enumerate(vsdin):
-                    ahunkin.append(np.zeros(shapein[ivsdin]))
+                    ahunkin.shape = shapein[ivsdin])
                     # apply the function
     
             ahunkout =  func(*ahunkin)
